@@ -27,6 +27,8 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 )
 
+var depMessage = "Deployment should be completed"
+
 func TestGenerateSecret(t *testing.T) {
 	scheme, err := api.SchemeBuilder.Build()
 	assert.Nil(t, err, "Failed to get scheme")
@@ -229,7 +231,7 @@ func TestSpecifySecret(t *testing.T) {
 		Spec: api.KieAppSpec{
 			Environment: api.RhpamTrial,
 			Objects: api.KieAppObjects{
-				Console: api.ConsoleObject{
+				Console: &api.ConsoleObject{
 					KieAppObject: api.KieAppObject{
 						KeystoreSecret: "console-ks-secret",
 					},
@@ -317,61 +319,75 @@ func TestVerifyExternalReferencesRoleMapper(t *testing.T) {
 	}, {
 		name: "Unsupported Kind: Service",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Service",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "unsupported Kind: Service",
 	}, {
 		name: "Not found ConfigMap",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "ConfigMap",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Not found Secret",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Secret",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Not found PersistentVolumeClaim",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "PersistentVolumeClaim",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Found ConfigMap",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "ConfigMap",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}, {
 		name: "Found Secret",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Secret",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}, {
 		name: "Found PersistentVolumeClaim",
 		roleMapper: &api.RoleMapperAuthConfig{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "PersistentVolumeClaim",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}}
@@ -426,61 +442,75 @@ func TestVerifyExternalReferencesGitHooks(t *testing.T) {
 	}, {
 		name: "Unsupported type",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Service",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "unsupported Kind: Service",
 	}, {
 		name: "Not found ConfigMap",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "ConfigMap",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Not found Secret",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Secret",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Not found PersistentVolumeClaim",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "PersistentVolumeClaim",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 		errMsg: "Mock: Not found",
 	}, {
 		name: "Found ConfigMap",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "ConfigMap",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}, {
 		name: "Found Secret",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "Secret",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}, {
 		name: "Found PersistentVolumeClaim",
 		gitHooks: &api.GitHooksVolume{
-			From: &corev1.ObjectReference{
-				Name: "test",
+			From: &api.ObjRef{
 				Kind: "PersistentVolumeClaim",
+				ObjectReference: api.ObjectReference{
+					Name: "test",
+				},
 			},
 		},
 	}}
@@ -492,7 +522,7 @@ func TestVerifyExternalReferencesGitHooks(t *testing.T) {
 		Spec: api.KieAppSpec{
 			Environment: api.RhdmTrial,
 			Objects: api.KieAppObjects{
-				Console: api.ConsoleObject{},
+				Console: &api.ConsoleObject{},
 			},
 		},
 	}
@@ -533,6 +563,13 @@ func TestCreateRhpamImageStreams(t *testing.T) {
 		},
 		Spec: api.KieAppSpec{
 			Environment: api.RhpamTrial,
+			Objects: api.KieAppObjects{
+				Console: &api.ConsoleObject{
+					KieAppObject: api.KieAppObject{
+						ImageContext: "test",
+					},
+				},
+			},
 		},
 	}
 	mockSvc := test.MockService()
@@ -543,13 +580,19 @@ func TestCreateRhpamImageStreams(t *testing.T) {
 		Service: mockSvc,
 	}
 
-	err = reconciler.createLocalImageTag(fmt.Sprintf("rhpam%s-businesscentral-openshift:1.0", cr.Status.Applied.Version), cr)
+	image := fmt.Sprintf("rhpam-businesscentral-openshift:%s", cr.Status.Applied.Version)
+	imageURL := constants.ImageRegistry + "/" + cr.Spec.Objects.Console.ImageContext + "/" + image
+	err = reconciler.createLocalImageTag(image, imageURL, cr)
 	assert.Nil(t, err)
 
-	isTag, err := isTagMock.Get(fmt.Sprintf("test-ns/rhpam%s-businesscentral-openshift:1.0", cr.Status.Applied.Version), metav1.GetOptions{})
+	isTag, err := isTagMock.Get(context.TODO(), cr.Namespace+"/"+image, metav1.GetOptions{})
 	assert.Nil(t, err)
+
 	assert.NotNil(t, isTag)
-	assert.Equal(t, fmt.Sprintf("registry.redhat.io/rhpam-7/rhpam%s-businesscentral-openshift:1.0", cr.Status.Applied.Version), isTag.Tag.From.Name)
+	assert.Equal(t, imageURL, isTag.Tag.From.Name)
+	assert.Equal(t, image, isTag.Name)
+	assert.Equal(t, cr.Status.Applied.Version, isTag.Tag.Name)
+	assert.Equal(t, cr.Namespace, isTag.Namespace)
 }
 
 func TestCreateRhdmImageStreams(t *testing.T) {
@@ -570,10 +613,10 @@ func TestCreateRhdmImageStreams(t *testing.T) {
 		Service: mockSvc,
 	}
 
-	err = reconciler.createLocalImageTag(fmt.Sprintf("rhdm%s-decisioncentral-openshift:1.0", cr.Status.Applied.Version), cr)
+	err = reconciler.createLocalImageTag(fmt.Sprintf("rhdm%s-decisioncentral-openshift:1.0", cr.Status.Applied.Version), "", cr)
 	assert.Nil(t, err)
 
-	isTag, err := isTagMock.Get(fmt.Sprintf("test-ns/rhdm%s-decisioncentral-openshift:1.0", cr.Status.Applied.Version), metav1.GetOptions{})
+	isTag, err := isTagMock.Get(context.TODO(), fmt.Sprintf("test-ns/rhdm%s-decisioncentral-openshift:1.0", cr.Status.Applied.Version), metav1.GetOptions{})
 	assert.Nil(t, err)
 	assert.NotNil(t, isTag)
 	assert.Equal(t, fmt.Sprintf("registry.redhat.io/rhdm-7/rhdm%s-decisioncentral-openshift:1.0", cr.Status.Applied.Version), isTag.Tag.From.Name)
@@ -597,10 +640,10 @@ func TestCreateTagVersionImageStreams(t *testing.T) {
 		Service: mockSvc,
 	}
 
-	err = reconciler.createLocalImageTag(fmt.Sprintf("%s:%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage, constants.VersionConstants[cr.Status.Applied.Version].DatagridImageTag), cr)
+	err = reconciler.createLocalImageTag(fmt.Sprintf("%s:%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage, constants.VersionConstants[cr.Status.Applied.Version].DatagridImageTag), "", cr)
 	assert.Nil(t, err)
 
-	isTag, err := isTagMock.Get(fmt.Sprintf("test-ns/%s:%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage, constants.VersionConstants[cr.Status.Applied.Version].DatagridImageTag), metav1.GetOptions{})
+	isTag, err := isTagMock.Get(context.TODO(), fmt.Sprintf("test-ns/%s:%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage, constants.VersionConstants[cr.Status.Applied.Version].DatagridImageTag), metav1.GetOptions{})
 	assert.Nil(t, err)
 	assert.NotNil(t, isTag)
 	assert.Equal(t, fmt.Sprintf("%s/jboss-datagrid-7/%s:%s", constants.ImageRegistry, constants.VersionConstants[cr.Status.Applied.Version].DatagridImage, constants.VersionConstants[cr.Status.Applied.Version].DatagridImageTag), isTag.Tag.From.Name)
@@ -624,10 +667,10 @@ func TestCreateImageStreamsLatest(t *testing.T) {
 		Service: mockSvc,
 	}
 
-	err = reconciler.createLocalImageTag(fmt.Sprintf("%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage), cr)
+	err = reconciler.createLocalImageTag(fmt.Sprintf("%s", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage), "", cr)
 	assert.Nil(t, err)
 
-	isTag, err := isTagMock.Get(fmt.Sprintf("test-ns/%s:latest", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage), metav1.GetOptions{})
+	isTag, err := isTagMock.Get(context.TODO(), fmt.Sprintf("test-ns/%s:latest", constants.VersionConstants[cr.Status.Applied.Version].DatagridImage), metav1.GetOptions{})
 	assert.Nil(t, err)
 	fmt.Print(isTag)
 	assert.NotNil(t, isTag)
@@ -657,6 +700,7 @@ func TestStatusDeploymentsProgression(t *testing.T) {
 	assert.Nil(t, err)
 
 	cr = reloadCR(t, service, crNamespacedName)
+	assert.NotEmpty(t, cr.Status.Conditions)
 	assert.Equal(t, api.ProvisioningConditionType, cr.Status.Conditions[0].Type)
 	assert.Len(t, cr.Status.Deployments.Stopped, 2, "Expect 2 stopped deployments")
 
@@ -676,7 +720,7 @@ func TestStatusDeploymentsProgression(t *testing.T) {
 
 	result, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
 	assert.Nil(t, err)
-	assert.Equal(t, reconcile.Result{Requeue: true}, result, "Deployment should be created but requeued for status updates")
+	assert.Equal(t, reconcile.Result{}, result, depMessage)
 
 	cr = reloadCR(t, service, crNamespacedName)
 	assert.Equal(t, api.ProvisioningConditionType, cr.Status.Conditions[0].Type)
@@ -698,7 +742,7 @@ func TestStatusDeploymentsProgression(t *testing.T) {
 
 	result, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
 	assert.Nil(t, err)
-	assert.Equal(t, reconcile.Result{Requeue: true}, result, "Deployment should be created but requeued for status updates")
+	assert.Equal(t, reconcile.Result{}, result, depMessage)
 
 	cr = reloadCR(t, service, crNamespacedName)
 	assert.Equal(t, api.ProvisioningConditionType, cr.Status.Conditions[0].Type)
@@ -755,7 +799,7 @@ func TestConsoleLinkCreation(t *testing.T) {
 
 	result, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
 	assert.Nil(t, err)
-	assert.Equal(t, reconcile.Result{Requeue: true}, result, "Deployment should be created but requeued for status updates")
+	assert.Equal(t, reconcile.Result{}, result, depMessage)
 
 	cr = reloadCR(t, service, crNamespacedName)
 	assert.Equal(t, api.ProvisioningConditionType, cr.Status.Conditions[0].Type)
@@ -777,7 +821,7 @@ func TestConsoleLinkCreation(t *testing.T) {
 
 	result, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
 	assert.Nil(t, err)
-	assert.Equal(t, reconcile.Result{Requeue: true}, result, "Deployment should be created but requeued for status updates")
+	assert.Equal(t, reconcile.Result{}, result, depMessage)
 
 	cr = reloadCR(t, service, crNamespacedName)
 	assert.Equal(t, api.ProvisioningConditionType, cr.Status.Conditions[0].Type)
@@ -799,7 +843,8 @@ func TestConsoleLinkCreation(t *testing.T) {
 	err = service.Update(context.TODO(), cr)
 	assert.Nil(t, err)
 
-	result, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
+	_, err = reconciler.Reconcile(reconcile.Request{NamespacedName: crNamespacedName})
+	assert.Nil(t, err)
 	cr = reloadCR(t, service, crNamespacedName)
 	assert.Len(t, cr.GetFinalizers(), 0)
 	consoleLink = &consolev1.ConsoleLink{}
